/*
 * $Id: Dynamic.m,v 1.2 2006/04/06 02:31:14 rh Exp $
 *
 * A simple example for complete, dynamic method invocation
 */

#include <stdio.h>
#import "Dynamic.h"

@implementation Dynamic

/*
 * dynamically create an object of the given class
 */
- createObject: (NSString *) className
{
	dynClass = NSClassFromString(className);

	if (!dynClass) return nil;	/* could not find class */

	dynObject = [dynClass new];	/* create an instance of class */

	return dynObject ? (id) self : nil;
}

/*
 * invoke the given method on the created class
 * this requires that createObject has successfully been called!
 */
- invokeMethod: (NSString *) methodName
{
	SEL method = NSSelectorFromString(methodName);

	return [dynObject performSelector: method];
}

/*
 * free resources
 */
- (void) dealloc
{
	[dynObject release];
	[super dealloc];
}

/*
 * a test method to invoke
 */
- test
{
	printf("This is the test method of the Dynamic class\n");

	return self;
}

@end /* Dynamic */

